package data;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.EntityListeners;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

import util.Assert;
import util.EntityListener;

@Entity
@Table(name = "TRU_MASTER")
@SequenceGenerator(name="SEQ_TRU", sequenceName = "SEQ_TRU", allocationSize=1)
@EntityListeners({EntityListener.class})
public class Master {
	@Id
	@GeneratedValue(strategy=GenerationType.SEQUENCE, generator = "SEQ_TRU")
	public Integer id = null;
	@OneToMany(targetEntity=Slave.class, mappedBy="master", cascade={CascadeType.ALL},fetch=FetchType.LAZY)
	public List<Slave> slaves = new ArrayList<Slave>();
	
	public void addSlave(Slave s) {
		Assert.isLegal(s.master == null);
		Assert.isLegal(!slaves.contains(s));
		slaves.add(s);
		s.master = this;
	}

	public void removeSlave(Slave s) {
		Assert.isLegal(s.master == this);
		Assert.isLegal(slaves.contains(s));
		slaves.remove(s);
		s.master = null;
	}

	public Slave addNewSlave() {
		final Slave s = new Slave();
		addSlave(s);
		return s;
	}
	
	@Override
	public String toString() {
		return super.toString()+" id = "+id;
	}
}
