package tests;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import data.Master;
import data.Slave;


public class PersistTest {
	
	public static void main(String[] args) {
		final EntityManagerFactory ef = Persistence.createEntityManagerFactory("bne");
		final EntityManager em = ef.createEntityManager();

		final int pairs = 1000;

		em.getTransaction().begin();

		final Master[] m = new Master[pairs];
		final Slave[] s = new Slave[pairs];
		
		for (int i = 0; i < pairs; ++i) {
			m[i] = new Master();
			em.persist(m[i]);
			System.out.println("persisted "+m[i]);
			s[i] = m[i].addNewSlave();
			// em.persist(s[i]); // persisting the slave EXPLICITLY seems to work
			System.out.println("added "+s[i]);
			// em.persist(m[i]); // persisting AFTER having added all salves seems to work
		}
		em.getTransaction().commit();
		System.out.println("committed");
		
		int[] e = {0,0,0,0};
		String[] emsg = {
				" masters not contained", " masters contained but no id",
				" slaves not contained", " slaves contained but no id"
		};
		
		for (int i = 0; i < pairs; ++i) {
			if (!em.contains(m[i])) {
				System.err.println(i+" "+m[i]+" is not contained!");
				++e[0];
			} else if (m[i].id == null) {
				System.err.println(i+" "+m[i]+" is contained but has no id!");
				++e[1];
			}
			if (!em.contains(s[i])) {
				System.err.println(i+" "+s[i]+" is not contained!");
				++e[2];
			} else if (s[i].id == null) {
				System.err.println(i+" "+s[i]+" is contained but has no id!");
				++e[3];
			}
		}
		
		for (int i = 0; i < 4; ++ i) {
			if (e[i] != 0) {
				System.err.println(e[i]+emsg[i]);
			}
		}
		System.out.println("good bey");

		em.close();
		ef.close();
	}
}
